.. currentmodule:: pdcast

pdcast/decorators/extension.py
==============================

Content of **pdcast/func/base.py**

.. literalinclude:: ../../../../../pdcast/decorators/base.py

Content of **pdcast/func/extension.py**

.. literalinclude:: ../../../../../pdcast/decorators/extension.py
